@@ -9,6 +9,25 @@ API_URL = "https://secure.runescape.com"
 LOGGER = logging.getLogger("rsapi")
 
 
+class ItemError(Exception):
+    def __init__(self, msg, query):
+        self.msg = msg
+        self.query = query
+
+
+class TooManyResults(ItemError):
+    def __init__(self, msg, query, items):
+        super().__init__(msg, query)
+        self.items = items
+
+    def __str__(self):
+        return f"TooManyResults: ('{self.msg}', '{self.query}', #'{len(self.items)}')"
+
+
+class PlayerNotFound(Exception):
+    pass
+
+
 def diff_scores(baseline, scores):
     deltas = {}
 
